scitex-container
================

Unified container management for Apptainer and Docker.

.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   installation
   quickstart

.. toctree::
   :maxdepth: 2
   :caption: User Guide

   cli_reference
   mcp_reference

.. toctree::
   :maxdepth: 2
   :caption: API Reference

   api/scitex_container

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
